@@ -43,7 +43,7 @@ from winswitch.util.process_util import dump_threads, start_dump_threads, exec_d
 debug_import("commands_util")
 from winswitch.util.commands_util import XMODMAP_COMMAND, XPRA_COMMAND, SSH_COMMAND, NXPROXY_COMMAND, VNC_COMMAND, XMING_COMMAND, RDESKTOP_COMMAND, XFREERDP_COMMAND, XTERM_COMMAND, WINSWITCH_SERVER_COMMAND
 debug_import("file_io")
-from winswitch.util.file_io import get_lock_dir, get_port_filename
+from winswitch.util.file_io import get_lock_dir, get_port_filename, load_binary_file
 debug_import("simple_logger")
 from winswitch.util.simple_logger import set_loggers_debug, msig
 debug_import("server_link")
@@ -411,6 +411,14 @@ class ClientBase:
 		self.settings.xkbmap_query = getkeymap("-query")
 
 	def may_populate_xmodmap(self):
+		if self.settings.custom_xmodmap_pm and self.settings.custom_xmodmap_pke:
+			pm_file = os.path.expanduser(self.settings.custom_xmodmap_pm)
+			pke_file = os.path.expanduser(self.settings.custom_xmodmap_pke)
+			if is_valid_file(pm_file) and is_valid_file(pke_file):
+				self.slog("using custom xmodmap files: %s and %s" % (pm_file, pke_file))
+				self.xmodmap_keys = load_binary_file(pke_file)
+				self.xmodmap_modifiers = load_binary_file(pm_file)
+				return
 		if not XMODMAP_COMMAND:
 			return
 		if OSX:
@@ -429,11 +437,10 @@ class ClientBase:
 				#parse output:
 				started = False
 				for line in out.splitlines():
-					if line.find("org.x.startx$"):
+					if line.endswith("org.x.startx"):
 						self.slog("found launchctl status for startx: %s" % line)
 						parts = line.split()
-						if len(parts)>=2:
-							started = parts[1]=="0"
+						started = parts[0].isdigit()
 						break
 				if not started:
 					self.slog("X server is not started, not detecting xmodmap (which would cause it to start)")
