@@ -501,14 +501,8 @@ class ServerLineConnection:
 			n2 = [int(x) for x in v2.split(".")]
 			assert len(n1)>=2
 			assert len(n2)>=2
-			if n1[:3]==[0,0,7] and n2[:3]==[0,0,7]:
-				#all versions 0.0.7.x are compatible with each other
-				return	True
-			if n1[:2]>=[0,1]:
-				#v0.1 onwards is compatible with 0.0.7.31 onwards
-				return	n2[:2]>=[0,1] or n2[:4]>=[0,0,7,31]
-			if n2[1]!=0:
-				return	n1[:2]>=[0,1] or n1[:4]>=[0,0,7,31]
+			#we no longer support versions older than 0.1
+			return n1[:3]>=[0,1] and n2[:3]>=[0,1]
 		except Exception, e:
 			self.serror("%s" % e, v1, v2)
 		return	False
