@@ -263,15 +263,11 @@ class ProtocolHandler:
 		self.send(START_SESSION, [uuid, session_type, screen_size, opts])
 
 	def send_shadow_session(self, ID, read_only, shadow_type, screen_size, options):
-		args = [ID, read_only, shadow_type]
-		if self.remote_app_version>=[0,12,2]:		#screen_size and options are only supported after v0.12.2
-			args += [screen_size, options]
+		args = [ID, read_only, shadow_type, screen_size, options]
 		self.send(SHADOW_SESSION, args)
 
 	def send_session_status(self, ID, status, actor, preload, screen_size):
-		data = [ID, status, actor, preload]
-		if self.remote_app_version>=[0,12,8]:		#screen_size is only supported after v0.12.8
-			data += [screen_size]
+		data = [ID, status, actor, preload, screen_size]
 		self.send(SET_SESSION_STATUS, data)
 
 	def send_session_icon(self, session, large):
@@ -473,14 +469,14 @@ class ProtocolHandler:
 	def request_session_sound(self, ID, start_or_stop, in_or_out, monitor, codec, codec_options):
 		""" Request the other end to stop/start session sound """
 		args = [ID, start_or_stop, in_or_out, monitor]
-		if self.remote_app_version>=[0,12,3] and start_or_stop:		#codec and codec options are only supported since 0.12.3
+		if start_or_stop:
 			args += [codec, codec_options]
 		self.send(REQUEST_SESSION_SOUND, args)
 
 	def receive_session_sound(self, ID, start_or_stop, in_or_out, monitor, port=None, codec=None, codec_options={}):
 		""" Tell the other end it can start/stop receiving/sending sound for the given session ID """
 		args = [ID, start_or_stop, in_or_out, monitor, port]
-		if self.remote_app_version>=[0,12,3] and start_or_stop:		#codec and codec options are only supported since 0.12.3
+		if start_or_stop:
 			args += [codec, codec_options]
 		self.send(RECEIVE_SESSION_SOUND, args)
 
@@ -639,12 +635,11 @@ class ProtocolHandler:
 		session.read_only = get_bool(args[17])
 		session.shadowed_display = args[18]
 		session.options = self.parse_opts(args[19])
-		if len(args)>=25:										#added in 0.12.0
-			session.can_export_sound = get_bool(args[20])
-			session.can_inport_sound = get_bool(args[21])
-			session.can_clone_sound = get_bool(args[22])
-			session.uses_sound_out = get_bool(args[23])
-			session.uses_sound_in = get_bool(args[24])
+		session.can_export_sound = get_bool(args[20])
+		session.can_inport_sound = get_bool(args[21])
+		session.can_clone_sound = get_bool(args[22])
+		session.uses_sound_out = get_bool(args[23])
+		session.uses_sound_in = get_bool(args[24])
 		if len(args)>=26:
 			session.user = args[25]
 		session.validate()
@@ -654,16 +649,14 @@ class ProtocolHandler:
 		session = self.server.remove_session_by_ID(session_id)
 		return	session is not None
 
-	def do_set_session_status(self, session_id, status, actor, preload, *args):
+	def do_set_session_status(self, session_id, status, actor, preload, screen_size, *args):
 		session = self.server.get_session(session_id)
 		if not session:
 			return False
 		session.set_status(status)
 		session.actor = actor
 		session.preload = get_bool(preload)
-		#version 0.12.8 onwards:
-		if len(args)>0 and len(args[0])>0:
-			session.screen_size = args[0]
+		session.screen_size = screen_size
 		self.server.touch()
 		return True
 
@@ -702,10 +695,9 @@ class ProtocolHandler:
 		command = ServerCommand(args[0], args[1], args[2], args[3], args[4])
 		command.menu_category = args[5]
 		command.type = args[6]
-		if len(args)>9:			#added in 0.12.2
-			command.uses_sound_in = get_bool(args[7])
-			command.uses_sound_out = get_bool(args[8])
-			command.uses_video = get_bool(args[9])
+		command.uses_sound_in = get_bool(args[7])
+		command.uses_sound_out = get_bool(args[8])
+		command.uses_video = get_bool(args[9])
 		if len(args)>10:
 			command.icon_names = parse_csv(args[10])
 		return command
