@@ -722,7 +722,7 @@ class WinSwitchClientChannel(twisted_protocols_basic.LineReceiver):
 		self.controller.disconnect_session(session, self.user.uuid)
 		return	False
 
-	def set_session_status(self, ID, status, actor, preload, *args):
+	def set_session_status(self, ID, status, actor, preload, screen_size, *args):
 		"""
 		Only a few session status updates are allowed from the client.
 		First we ensure that the client is the actor.
@@ -746,9 +746,7 @@ class WinSwitchClientChannel(twisted_protocols_basic.LineReceiver):
 			else:
 				self.sdebug("session=%s already in correct state (no longer the owner!)" % session, ID, status, actor, preload, *args)
 			return False
-		#version 0.12.8 onwards:
-		if len(args)>0 and len(args[0])>0:
-			session.screen_size = args[0]
+		session.screen_size = screen_size
 		display_util = self.controller.get_remote_util(session.session_type)
 		assert display_util
 		if session.status==status or display_util.can_client_set_status(session, self.user.uuid, session.status, status):
