@@ -438,17 +438,20 @@ def load_menu_file(menu_dir, filename, req_cmd, ignored_commands=None, whitelist
 	if categories_list:
 		categories = sorted(categories_list.split(";"))
 		for cat in categories:
+			if not cat:
+				continue
 			if cat in disabled_categories:
 				skipped.append(name)
 				if may_ignore:
 					enabled = False
 			if cat.startswith("X-") or cat=="":
 				categories.remove(cat)
-			if cat in DEFAULT_SOUNDOUT_CATEGORIES:
+			cat = cat.lower()
+			if matches_any(cat, DEFAULT_SOUNDOUT_CATEGORIES):
 				uses_sound_out = True
-			if cat in DEFAULT_SOUNDIN_CATEGORIES:
+			if matches_any(cat, DEFAULT_SOUNDIN_CATEGORIES):
 				uses_sound_in = True
-			if cat in DEFAULT_VIDEO_CATEGORIES:
+			if matches_any(cat, DEFAULT_VIDEO_CATEGORIES):
 				uses_video = True
 
 	names = {}
@@ -487,6 +490,7 @@ def load_menu_file(menu_dir, filename, req_cmd, ignored_commands=None, whitelist
 	sc.uses_sound_out = uses_sound_out
 	sc.uses_sound_in = uses_sound_in
 	sc.uses_video = uses_video
+	logger.log("load_menu_file(..) %s.uses_video=%s" % (full_path, uses_video))
 	sc.run_once_only = run_once_only
 	pos = filename.rfind(".")
 	if pos>0:
@@ -510,17 +514,24 @@ def load_menu_file(menu_dir, filename, req_cmd, ignored_commands=None, whitelist
 
 
 
-def matches_any(x, list_of_regexps):
+def matches_any(x, list_of_regexps, _debug=False):
 	if not list_of_regexps or not x:
+		if _debug:
+			logger.sdebug("no regexps or no value!", x, list_of_regexps)
 		return None
 	for v in list_of_regexps:
 		#straight match
 		if x==v:
+			if _debug:
+				logger.sdebug("direct match!", x, list_of_regexps)
 			return	v
 		# substring match, convert to a RE
 		rstr = r"^%s$" % v.replace("*", ".*")
 		regexp = re.compile(rstr)
-		if regexp.match(x):
+		m = regexp.match(x)
+		if _debug:
+			logger.sdebug("%s.match(%s)=%s" % (rstr, x, m), x, list_of_regexps)
+		if m:
 			return	v
 	return	None
 
@@ -541,9 +552,9 @@ def main():
 	LOG_MENU = True
 	logger.slog()
 	logger.slog("default_browse_command=%s" % get_default_browse_command())
-	logger.slog("xsessions=%s" % load_xsessions())
+	logger.slog("xsessions=%s" % load_xsessions([], []))
 	logger.slog("actions=%s" % load_actions())
-	(commands, categories) = load_start_menu(DEFAULT_IGNORED_COMMANDS)
+	(commands, categories) = load_start_menu(DEFAULT_IGNORED_COMMANDS, [])
 	logger.slog("start_menu commands=%s" % csv_list(commands))
 	logger.slog("start_menu categories=%s" % csv_list(categories))
 
